# PREPARING PARAMETER FILE FOR RENUMF90
rm -f renum.par
echo "# parameter file for renumf90
DATAFILE
data3.txt
TRAITS
4 
FIELDS_PASSED TO OUTPUT
2 5 
WEIGHT(S)
 
RESIDUAL_VARIANCE
0.60 
EFFECT
3 cross alpha
EFFECT
1 cross alpha 
RANDOM
animal
FILE
ped3.txt
FILE_POS
1 2 3 0 0 
SNP_FILE
snp3.2k 
PED_DEPTH
3 
INBREEDING
pedigree 
(CO)VARIANCES
0.40" >> renum.par

# RUNNING RENUMF90
./renumf90 renum.par | tee renum.log

# RUNNING PREGSF90
echo "OPTION saveCleanSNPs
OPTION msg 100" >> renf90.par
time ./preGSf90 renf90.par | tee pregs.log

# RUNNING BLUPF90+ WITH AND WITHOUT GENOMICS
# WITH
# AI-REML
sed -i -e '/OPTION saveCleanSNPs/d' renf90.par
sed -i -e "s/OPTION SNP_file snp3.2k/OPTION SNP_file snp3.2k_clean/g" renf90.par
echo "OPTION no_quality_control" >> renf90.par
echo "OPTION method VCE" >> renf90.par
time ./blupf90+ renf90.par | tee vceg1.log
# EM-REML
echo "OPTION EM-REML pure" >> renf90.par
time ./blupf90+ renf90.par | tee vceg2.log
# WITHOUT
# EM-REML
sed -i -e '/OPTION SNP_file snp3.2k_clean/d' renf90.par
time ./blupf90+ renf90.par | tee vcep1.log
# AI-REML
sed -i -e '/OPTION EM-REML pure/d' renf90.par
time ./blupf90+ renf90.par | tee vcep2.log


# COMPUTING EBV AND GEBV
sed -i -e '/OPTION method VCE/d' renf90.par
sed -i -e '/OPTION msg 100/d' renf90.par
echo "OPTION store_accuracy 2 orig" >> renf90.par
# EBV
time ./blupf90+ renf90.par | tee blup_ebv.log
mv acc_bf90 acc_bf90_p
mv solutions sol_pebv_whole
# GEBV
echo "OPTION SNP_file snp3.2k_clean" >> renf90.par
time ./blupf90+ renf90.par | tee blup_gebv.log
mv acc_bf90 acc_bf90_g
mv solutions sol_gebv_whole

# VALIDATION
awk '$4 < 5 {print $0}' renf90.dat > renf90.dat.reduced
sed -i -e 's/renf90.dat/renf90.dat.reduced/g' renf90.par
# WITH
sed -i -e '/OPTION store_accuracy 2 orig/d' renf90.par
time ./blupf90+ renf90.par
mv solutions sol_gebv_reduced
# WITHOUT
sed -i -e '/OPTION SNP_file snp3.2k_clean/d' renf90.par
time ./blupf90+ renf90.par
mv solutions sol_pebv_reduced
# PUTTING ALL TOGETHER
awk '$4 == 5 {print $3,$5}' renf90.dat > tbv.temp
awk '$2 == 2 {print $3,$4}' sol_pebv_whole > pebvw.temp
awk '$2 == 2 {print $3,$4}' sol_pebv_reduced > pebvr.temp
awk '$2 == 2 {print $3,$4}' sol_gebv_whole > gebvw.temp
awk '$2 == 2 {print $3,$4}' sol_gebv_reduced > gebvr.temp
awk '{print $1,$2}' renf90.inb > inb.temp
awk '{print $10,$1}' renadd02.ped > idped.temp
awk 'NR == FNR {a[$1]=$2;next} ($1 in a) {print $2,a[$1]}' inb.temp idped.temp > sol.final
awk 'NR == FNR {a[$1]=$0;next} ($1 in a) {print a[$1],$2}' sol.final tbv.temp > temp && mv temp sol.final
awk 'NR == FNR {a[$1]=$0;next} ($1 in a) {print a[$1],$2}' sol.final pebvw.temp > temp && mv temp sol.final
awk 'NR == FNR {a[$1]=$0;next} ($1 in a) {print a[$1],$2}' sol.final pebvr.temp > temp && mv temp sol.final
awk 'NR == FNR {a[$1]=$0;next} ($1 in a) {print a[$1],$2}' sol.final gebvw.temp > temp && mv temp sol.final
awk 'NR == FNR {a[$1]=$0;next} ($1 in a) {print a[$1],$2}' sol.final gebvr.temp > temp && mv temp sol.final
rm *.temp
# R
rm -f val.R
echo "sol <- read.table('sol.final')
names(sol) <- c('IDr','INB','TBV','EBVw','EBVp','GEBVw','GEBVp')
head(sol)
print('correlation')
round(cor(sol[,c(3,5,7)]),2)
print('regression TBV ~ EBVp')
round(coef(lm(sol[,3] ~ sol[,5]))[2],2)
print('regression TBV ~ GEBVp')
round(coef(lm(sol[,3] ~ sol[,7]))[2],2)
print('Bias EBV')
round(mean(sol[,5] - sol[,4]),2)
print('Bias GEBV')
round(mean(sol[,7] - sol[,6]),2)
print('Regression EBVw ~ EBVp')
round(cov(sol[,5],sol[,4])/var(sol[,5]),2)
print('Regression GEBVw ~ GEBVp')
round(cov(sol[,6],sol[,7])/var(sol[,7]),2)
print('Correlation EBVw - EBVp')
round(cor(sol[,5],sol[,4]),2)
print('Correlation GEBVw - GEBVp')
round(cor(sol[,6],sol[,7]),2)
print('LR Accuracy EBV')
round(sqrt(cov(sol[,5],sol[,4])/((1 - mean(sol[,2])) * 0.40)),2)
print('LR Accuracy GEBV')
round(sqrt(cov(sol[,7],sol[,6])/((1 - mean(sol[,2])) * 0.40)),2)" >> val.R
Rscript val.R
